<h1 align="center">R3B Website and NUSTAR Member Database</h1>

## Overview

This app contains the public website for R3B as well as the NUSTAR member database implemented in full stack NextJS. The public website is using the Payload (v3) for content management.

## Technology Stack

| Technology | Purpose |
|------------|---------|
| [Next.js](https://nextjs.org/) | Full-stack framework for both frontend and backend |
| [Payload CMS](https://payloadcms.com/) | Content management for the R3B website |
| [TailwindCSS](https://tailwindcss.com) | Utility-first CSS framework |
| [MongoDB](https://www.mongodb.com/) | Database for Payload CMS data |
| [SQLite](https://www.sqlite.org/) | Database for NUSTAR member information |
| [pnpm](https://pnpm.io/) | Fast, disk space efficient package manager |

## Prerequisites

- Docker and Docker Compose
- Node.js 18+
- pnpm 8+ (`npm install -g pnpm`)
- Git

## Installation

1. Clone the repository:
   ```bash
   git clone [repository-url]
   cd nustar-r3b
   ```

2. Install dependencies (only when running locally, without docker):
   ```bash
   # When running locally
   pnpm install
   ```

3. Set up environment variables:
   ```bash
   cp .env.example .env
   ```

   > :warning: **WARNING:**
   > The default payload secret in `.env.example` is for development only. Always use a secure secret in production.

4. Start the application:
   ```bash
   # Using Docker (recommended)
   docker compose up -d

   # Or using pnpm for local development
   pnpm dev
   ```
    > ℹ **NOTE:**
    > When running locally, change `DATABASE_URI` from `mongodb://mongo/nustar-r3b` to `mongodb://127.0.0.1/nustar-r3b` inside .env.

## Development Setup

### IDE Configuration

This project uses [antfu/eslint-config](https://github.com/antfu/eslint-config) for consistent code styling and linting.

#### Visual Studio Code
1. Install the [ESLint extension](https://marketplace.visualstudio.com/items?itemName=dbaeumer.vscode-eslint)
2. Install [pnpm](https://pnpm.io/installation)
3. Run `pnpm install` inside the project directory
4. The provided `.vscode` configuration already enables auto-fix on save

#### Neovim
- Follow the [official documentation](https://github.com/antfu/eslint-config?tab=readme-ov-file#ide-support-auto-fix-on-save) for auto-fix on save setup

## Project Architecture

<p align="center">
  <img src="./docs/res/Architecture.png" width="800" alt="Project Architecture">
</p>
