PRAGMA foreign_keys = ON;
BEGIN TRANSACTION;

-- Base tables with no dependencies
CREATE TABLE IF NOT EXISTS Gender (
    Id INTEGER PRIMARY KEY NOT NULL,
    Short TEXT,
    Long TEXT
);

CREATE TABLE IF NOT EXISTS AcademicTitle (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT
);

CREATE TABLE IF NOT EXISTS AcademicStatus (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT
);

CREATE TABLE IF NOT EXISTS Country (
    Id INTEGER PRIMARY KEY NOT NULL,
    ISO_alpha2 TEXT UNIQUE,
    ISO_alpha3 TEXT UNIQUE,
    ISO_Numeric TEXT,
    Name TEXT UNIQUE
);

CREATE TABLE IF NOT EXISTS Institute (
    Id INTEGER PRIMARY KEY NOT NULL,
    Acronym TEXT,
    Name TEXT,
    Address1 TEXT,
    Address2 TEXT,
    Address3 TEXT,
    Address4 TEXT,
    Phone TEXT,
    Fax TEXT,
    City TEXT,
    Zip TEXT,
    CountryId INTEGER REFERENCES Country(Id),
    AddressForPublication TEXT
);

CREATE TABLE IF NOT EXISTS Person (
    Id INTEGER PRIMARY KEY NOT NULL,
    AcademicStatusId INTEGER REFERENCES AcademicStatus(Id),
    AcademicTitleId INTEGER REFERENCES AcademicTitle(Id),
    FirstName TEXT,
    MiddleNames TEXT,
    LastName TEXT,
    GenderId INTEGER REFERENCES Gender(Id),
    Phone TEXT,
    Email TEXT,
    MainInstituteId INTEGER REFERENCES Institute(Id),
    InactiveFlag INTEGER
);

CREATE TABLE IF NOT EXISTS Collaboration (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT,
    Label TEXT,
    Website TEXT,
    MembershipFlag INTEGER
);

CREATE TABLE IF NOT EXISTS WorkGroup (
    Id INTEGER PRIMARY KEY NOT NULL,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    Name TEXT,
    Label TEXT
);

CREATE TABLE IF NOT EXISTS CollaborationFunction (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT,
    Hierarchy INTEGER
);

CREATE TABLE IF NOT EXISTS WorkgroupFunction (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT
);

CREATE TABLE IF NOT EXISTS ExperimentKeyword (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT
);

CREATE TABLE IF NOT EXISTS ExperimentContribution (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT
);

CREATE TABLE IF NOT EXISTS ResearcherIdentification (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT
);

CREATE TABLE IF NOT EXISTS Board (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    Hierarchy INTEGER
);

CREATE TABLE IF NOT EXISTS EmailList (
    Id INTEGER PRIMARY KEY NOT NULL,
    Email TEXT,
    Name TEXT,
    Description TEXT,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    SupervisorId INTEGER REFERENCES Person(Id),
    SupervisorApprovalFlag INTEGER
);

-- Tables with dependencies
CREATE TABLE IF NOT EXISTS Supervisor (
    Id INTEGER PRIMARY KEY NOT NULL,
    PersonId INTEGER REFERENCES Person(Id),
    SupervisorId INTEGER REFERENCES Person(Id)
);

CREATE TABLE IF NOT EXISTS AdditionalEmail (
    PersonId INTEGER REFERENCES Person(Id),
    Email TEXT
);

CREATE TABLE IF NOT EXISTS AdditionalInstituteAffiliations (
    PersonId INTEGER REFERENCES Person(Id),
    InstituteId INTEGER REFERENCES Institute(Id)
);

CREATE TABLE IF NOT EXISTS CollaborationMembers (
    PersonId INTEGER REFERENCES Person(Id),
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    ExpirationDate TEXT,
    TechnicalStaffFlag INTEGER
);

CREATE TABLE IF NOT EXISTS EmailListMembers (
    PersonId INTEGER REFERENCES Person(Id),
    EmailListId INTEGER REFERENCES EmailList(Id)
);

CREATE TABLE IF NOT EXISTS WorkgroupMembers (
    PersonId INTEGER REFERENCES Person(Id),
    WorkgroupId INTEGER REFERENCES WorkGroup(Id),
    ExpirationDate TEXT
);

CREATE TABLE IF NOT EXISTS WorkgroupFunctions (
    PersonId INTEGER REFERENCES Person(Id),
    WorkgroupId INTEGER REFERENCES WorkGroup(Id),
    WorkgroupFunctionId INTEGER REFERENCES WorkgroupFunction(Id)
);

CREATE TABLE IF NOT EXISTS Experiment (
    Id INTEGER PRIMARY KEY NOT NULL,
    Name TEXT,
    SupervisorId INTEGER REFERENCES Person(Id),
    SupervisorApprovalFlag INTEGER,
    Facility TEXT,
    Year INTEGER,
    PhDRelevantFlag INTEGER,
    Proposal TEXT,
    ProposalLink TEXT,
    CollaborationId INTEGER REFERENCES Collaboration(Id)
);

CREATE TABLE IF NOT EXISTS ExperimentMembers (
    ExperimentId INTEGER REFERENCES Experiment(Id),
    PersonId INTEGER REFERENCES Person(Id)
);

CREATE TABLE IF NOT EXISTS ExperimentKeywords (
    ExperimentId INTEGER REFERENCES Experiment(Id),
    KeywordId INTEGER REFERENCES ExperimentKeyword(Id)
);

CREATE TABLE IF NOT EXISTS ExperimentMemberAffiliation (
    ExperimentMemberId INTEGER REFERENCES ExperimentMembers(ExperimentId),
    AffiliationId INTEGER REFERENCES Institute(Id)
);

CREATE TABLE IF NOT EXISTS ExperimentContributions (
    ExperimentId INTEGER REFERENCES Experiment(Id),
    PersonId INTEGER REFERENCES Person(Id),
    ExperimentContributionId INTEGER REFERENCES ExperimentContribution(Id),
    GroupCoordinatorId INTEGER REFERENCES Person(Id),
    TimeStart TEXT,
    TimeStop TEXT,
    Comment TEXT
);

CREATE TABLE IF NOT EXISTS ResearcherIdentifications (
    ResearcherIdentificationId INTEGER REFERENCES ResearcherIdentification(Id),
    PersonId INTEGER REFERENCES Person(Id),
    Name TEXT
);

CREATE TABLE IF NOT EXISTS BoardAutomatic (
    BoardId INTEGER REFERENCES Board(Id),
    Reason TEXT,
    SQL TEXT
);

CREATE TABLE IF NOT EXISTS BoardMembers (
    BoardId INTEGER REFERENCES Board(Id),
    PersonId INTEGER REFERENCES Person(Id),
    InstituteId INTEGER REFERENCES Institute(Id),
    CollaborationFunctionId INTEGER REFERENCES CollaborationFunction(Id),
    ElectionDate TEXT,
    ElectionNote TEXT
);

CREATE TABLE IF NOT EXISTS BoardRotation (
    BoardId INTEGER REFERENCES Board(Id),
    CollaborationFunctionId INTEGER REFERENCES CollaborationFunction(Id),
    RotationPeriod INTEGER
);

CREATE TABLE IF NOT EXISTS EmailListCc (
    Id INTEGER PRIMARY KEY NOT NULL,
    SupervisorApprovalFlag INTEGER,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    WorkgroupId INTEGER REFERENCES WorkGroup(Id)
);

CREATE TABLE IF NOT EXISTS EmailListCcMembers (
    EmailListCcId INTEGER REFERENCES EmailListCc(Id),
    PersonId INTEGER REFERENCES Person(Id)
);

CREATE TABLE IF NOT EXISTS EmailForward (
    Id INTEGER PRIMARY KEY NOT NULL,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    EmailName TEXT,
    Email TEXT
);

CREATE TABLE IF NOT EXISTS CollaborationWebsite (
    Id INTEGER PRIMARY KEY NOT NULL,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    URL TEXT,
    LinkName TEXT,
    Description TEXT
);

CREATE TABLE IF NOT EXISTS BoardMeeting (
    Id INTEGER PRIMARY KEY NOT NULL,
    BoardId TEXT REFERENCES Board(Id),
    Date TEXT DEFAULT CURRENT_DATE,
    Place TEXT
);

CREATE TABLE IF NOT EXISTS BoardMeetingAttendance (
    Id INTEGER PRIMARY KEY NOT NULL,
    BoardMeetingId TEXT REFERENCES BoardMeeting(Id),
    PersonId INTEGER REFERENCES Person(Id),
    InstituteId INTEGER REFERENCES Institute(Id)
);

CREATE TABLE IF NOT EXISTS CollaborationAgreement (
    Id INTEGER PRIMARY KEY NOT NULL,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    BoardMeetingId INTEGER REFERENCES BoardMeeting(Id),
    IsCurrent BOOLEAN,
    EMailURL TEXT DEFAULT 'https://www.r3b-nustar.de/member/db/mailarchive/r3b-collaboration-board/'
);

CREATE TABLE IF NOT EXISTS BoardMembershipStatus (
    Id INTEGER PRIMARY KEY NOT NULL,
    CollaborationAgreementId INTEGER REFERENCES CollaborationAgreement(Id),
    PersonId INTEGER REFERENCES Person(Id),
    InstituteId INTEGER REFERENCES Institute(Id),
    CaSignedOn TEXT DEFAULT CURRENT_DATE
);

CREATE TABLE IF NOT EXISTS MemberFeeType (
    Id INTEGER PRIMARY KEY NOT NULL,
    MemberFeeType TEXT
);

CREATE TABLE IF NOT EXISTS CollaborationMemberFee (
    Id INTEGER PRIMARY KEY NOT NULL,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    PersonId INTEGER REFERENCES Person(Id),
    InstituteId INTEGER REFERENCES Institute(Id),
    MemberFeeTypeId INTEGER REFERENCES MemberFeeType(Id),
    ForYear TEXT
);

CREATE TABLE IF NOT EXISTS Request (
    Id INTEGER PRIMARY KEY NOT NULL,
    Time TEXT,
    SubmitterId INTEGER REFERENCES Person(Id),
    AddresserId INTEGER REFERENCES Person(Id),
    EmailText TEXT,
    TableName TEXT,
    SQL TEXT,
    Value TEXT,
    Key TEXT,
    CollaborationId INTEGER REFERENCES Collaboration(Id),
    ExecTime TEXT,
    ExecPersonId INTEGER REFERENCES Person(Id),
    ExecState INTEGER
);

-- Special tables
CREATE TABLE IF NOT EXISTS SPECIAL_Permission (
    TableName TEXT,
    Read TEXT,
    Write TEXT,
    SQL TEXT
);

CREATE TABLE IF NOT EXISTS SPECIAL_RelationInfo (
    TableName TEXT,
    TableHeader TEXT,
    Description TEXT,
    HelpText TEXT
);

CREATE TABLE IF NOT EXISTS SPECIAL_ColumnInfo (
    TableName TEXT,
    ColumnName TEXT,
    ColumnHeader TEXT,
    HelpText TEXT,
    ExampleText TEXT
);

CREATE TABLE IF NOT EXISTS SPECIAL_ShortSpec (
    TableId INTEGER REFERENCES sqlite_master(rowid),
    SQL TEXT
);

COMMIT;
