BEGIN TRANSACTION;

-- Gender data
INSERT INTO Gender (Id, Short, Long) VALUES
(1, 'M', 'Male'),
(2, 'F', 'Female'),
(3, 'O', 'Other');

-- Academic titles
INSERT INTO AcademicTitle (Id, Name) VALUES
(1, 'Dr.'),
(2, 'Prof.'),
(3, 'Prof. Dr.'),
(4, 'M.Sc.'),
(5, 'B.Sc.');

-- Academic status
INSERT INTO AcademicStatus (Id, Name) VALUES
(1, 'Ph.D. Student'),
(2, 'Postdoc'),
(3, 'Senior Scientist'),
(4, 'Professor'),
(5, 'Graduate Student');

-- Countries
INSERT INTO Country (Id, ISO_alpha2, ISO_alpha3, ISO_Numeric, Name) VALUES
(1, 'DE', 'DEU', '276', 'Germany'),
(2, 'US', 'USA', '840', 'United States'),
(3, 'GB', 'GBR', '826', 'United Kingdom'),
(4, 'FR', 'FRA', '250', 'France'),
(5, 'IT', 'ITA', '380', 'Italy');

-- Institutes
INSERT INTO Institute (Id, Acronym, Name, Address1, Address2, City, Zip, CountryId, Phone, Fax, AddressForPublication) VALUES
(1, 'IKDA', 'Institut für Kernphysik', 'Schlossgartenstraße 9', NULL, 'Darmstadt', '64289', 1, '+49-6151-16-21575', '+49-6151-16-21575', 'Institut für Kernphysik, TU Darmstadt'),
(2, 'CERN', 'European Organization for Nuclear Research', '1211 Geneva 23', NULL, 'Geneva', '1211', 4, '+41-22-767-61-11', '+41-22-767-61-11', 'CERN'),
(3, 'MIT', 'Massachusetts Institute of Technology', '77 Massachusetts Ave', NULL, 'Cambridge', '02139', 2, '+1-617-253-1000', '+1-617-253-1001', 'MIT Physics'),
(4, 'GSI', 'GSI Helmholtzzentrum', 'Planckstraße 1', NULL, 'Darmstadt', '64291', 1, '+49-6159-71-0', '+49-6159-71-2785', 'GSI Darmstadt');

-- People
INSERT INTO Person (Id, AcademicStatusId, AcademicTitleId, FirstName, MiddleNames, LastName, GenderId, Phone, Email, MainInstituteId, InactiveFlag) VALUES
(1, 4, 3, 'Hans', NULL, 'Schmidt', 1, '+49-6151-16-21580', 'hans.schmidt@physics.de', 1, 0),
(2, 2, 1, 'Marie', 'Claire', 'Laurent', 2, '+41-22-767-61-12', 'marie.laurent@cern.ch', 2, 0),
(3, 1, 5, 'John', NULL, 'Smith', 1, '+1-617-253-1001', 'jsmith@mit.edu', 3, 0),
(4, 3, 1, 'Anna', NULL, 'Müller', 2, '+49-6151-16-21581', 'anna.mueller@physics.de', 1, 0),
(5, 2, 1, 'Thomas', 'James', 'Wilson', 1, '+44-1235-445000', 'wilson@physics.ox.ac.uk', 2, 0);

-- Additional Email
INSERT INTO AdditionalEmail (PersonId, Email) VALUES
(1, 'hans.schmidt@gmail.com'),
(2, 'marie.laurent@gmail.com'),
(3, 'johnsmith@gmail.com');

-- Collaborations
INSERT INTO Collaboration (Id, Name, Label, Website, MembershipFlag) VALUES
(1, 'R3B', 'Reactions with Relativistic Radioactive Beams', 'https://www.r3b-collaboration.eu', 1),
(2, 'ATLAS', 'ATLAS Experiment', 'https://atlas.cern', 1),
(3, 'NUSTAR', 'Nuclear Structure, Astrophysics and Reactions', 'https://www.nustar.eu', 1);

-- Collaboration functions
INSERT INTO CollaborationFunction (Id, Name, Hierarchy) VALUES
(1, 'Spokesperson', 1),
(2, 'Deputy Spokesperson', 2),
(3, 'Technical Coordinator', 3),
(4, 'Physics Coordinator', 3),
(5, 'Computing Coordinator', 4);

-- Work groups
INSERT INTO WorkGroup (Id, CollaborationId, Name, Label) VALUES
(1, 1, 'Detector Development', 'DET-DEV'),
(2, 1, 'Data Analysis', 'DATA-AN'),
(3, 2, 'Computing', 'COMP'),
(4, 3, 'Theory', 'THEORY');

-- Workgroup functions
INSERT INTO WorkgroupFunction (Id, Name) VALUES
(1, 'Leader'),
(2, 'Deputy Leader'),
(3, 'Secretary'),
(4, 'Technical Contact');

-- Supervisors
INSERT INTO Supervisor (Id, PersonId, SupervisorId) VALUES
(1, 3, 1),
(2, 4, 2),
(3, 5, 1);

-- Additional Institute Affiliations
INSERT INTO AdditionalInstituteAffiliations (PersonId, InstituteId) VALUES
(1, 2),
(2, 3),
(3, 1);

-- Collaboration members
INSERT INTO CollaborationMembers (PersonId, CollaborationId, ExpirationDate, TechnicalStaffFlag) VALUES
(1, 1, '2025-12-31', 0),
(2, 1, '2025-12-31', 0),
(3, 2, '2025-12-31', 0),
(4, 3, '2025-12-31', 0),
(5, 1, '2025-12-31', 1);

-- Email lists
INSERT INTO EmailList (Id, Email, Name, Description, CollaborationId, SupervisorId, SupervisorApprovalFlag) VALUES
(1, 'r3b-all@lists.org', 'R3B General', 'General mailing list for R3B collaboration', 1, 1, 1),
(2, 'atlas-comp@lists.org', 'ATLAS Computing', 'Computing group mailing list', 2, 3, 1),
(3, 'nustar-board@lists.org', 'NUSTAR Board', 'NUSTAR collaboration board list', 3, 4, 1);

-- Email list members
INSERT INTO EmailListMembers (PersonId, EmailListId) VALUES
(1, 1),
(2, 1),
(3, 2),
(4, 3);

-- Workgroup members
INSERT INTO WorkgroupMembers (PersonId, WorkgroupId, ExpirationDate) VALUES
(1, 1, '2025-12-31'),
(2, 1, '2025-12-31'),
(3, 2, '2025-12-31'),
(4, 3, '2025-12-31');

-- Workgroup functions
INSERT INTO WorkgroupFunctions (PersonId, WorkgroupId, WorkgroupFunctionId) VALUES
(1, 1, 1),
(2, 1, 2),
(3, 2, 1),
(4, 3, 1);

-- SPECIAL Permission
INSERT INTO SPECIAL_Permission (TableName, Read, Write, SQL) VALUES
('Person', 'ALL', 'ADMIN', 'SELECT username FROM users WHERE role = ''admin'''),
('Collaboration', 'ALL', 'COLLAB_ADMIN', 'SELECT username FROM users WHERE role = ''collab_admin'''),
('WorkGroup', 'ALL', 'GROUP_LEADER', 'SELECT username FROM users WHERE role = ''group_leader''');

-- SPECIAL RelationInfo
INSERT INTO SPECIAL_RelationInfo (TableName, TableHeader, Description, HelpText) VALUES
('WorkGroup', 'Work Group', 'Please select your work group', 'Select the work group you want to join'),
('Collaboration', 'Collaboration', 'Choose collaboration', 'Select the collaboration you want to join'),
('Institute', 'Institute', 'Select institute', 'Choose your primary institute affiliation');

-- SPECIAL ColumnInfo
INSERT INTO SPECIAL_ColumnInfo (TableName, ColumnName, ColumnHeader, HelpText, ExampleText) VALUES
('Person', 'AcademicTitleId', 'Academic Title', 'Please select your academic title', 'Dr.'),
('Person', 'Email', 'Email Address', 'Enter your institutional email address', 'name@institution.edu'),
('Institute', 'Acronym', 'Institute Acronym', 'Short name of the institute', 'CERN');

-- SPECIAL ShortSpec
INSERT INTO SPECIAL_ShortSpec (TableId, SQL) VALUES
(1, 'SELECT Country.ISO_alpha3 || ''-'' || Institute.Acronym AS ShortDesc FROM Institute, Country WHERE Institute.CountryId=Country.Id');

-- Experiment Keywords
INSERT INTO ExperimentKeyword (Id, Name) VALUES
(1, 'Nuclear Physics'),
(2, 'Particle Physics'),
(3, 'Detector Development'),
(4, 'Data Analysis');

-- Experiments
INSERT INTO Experiment (Id, Name, SupervisorId, SupervisorApprovalFlag, Facility, Year, PhDRelevantFlag, Proposal, ProposalLink, CollaborationId) VALUES
(1, 'Heavy Ion Collision Study', 1, 1, 'GSI', 2024, 1, 'Study of heavy ion collisions', 'https://example.com/proposal1', 1),
(2, 'Neutron Detection', 2, 1, 'CERN', 2024, 1, 'New neutron detector development', 'https://example.com/proposal2', 2);

-- Experiment Members
INSERT INTO ExperimentMembers (ExperimentId, PersonId) VALUES
(1, 1),
(1, 2),
(2, 3),
(2, 4);

-- Experiment Keywords
INSERT INTO ExperimentKeywords (ExperimentId, KeywordId) VALUES
(1, 1),
(1, 3),
(2, 2),
(2, 3);

-- Experiment Member Affiliations
INSERT INTO ExperimentMemberAffiliation (ExperimentMemberId, AffiliationId) VALUES
(1, 1),
(2, 2),
(3, 3);

-- Email List CC
INSERT INTO EmailListCc (Id, SupervisorApprovalFlag, CollaborationId, WorkgroupId) VALUES
(1, 1, 1, 1),
(2, 1, 2, 2);

-- Email List CC Members
INSERT INTO EmailListCcMembers (EmailListCcId, PersonId) VALUES
(1, 1),
(1, 2),
(2, 3);

-- Researcher Identification
INSERT INTO ResearcherIdentification (Id, Name) VALUES
(1, 'ORCID'),
(2, 'ResearcherID'),
(3, 'Scopus Author ID');

-- Researcher Identifications
INSERT INTO ResearcherIdentifications (ResearcherIdentificationId, PersonId, Name) VALUES
(1, 1, '0000-0002-1825-0097'),
(2, 2, '0000-0001-5109-3700'),
(3, 3, '0000-0002-8627-0591');

-- Experiment Contribution
INSERT INTO ExperimentContribution (Id, Name) VALUES
(1, 'Hardware Development'),
(2, 'Software Development'),
(3, 'Data Analysis'),
(4, 'Shift Work');

-- Experiment Contributions
INSERT INTO ExperimentContributions (ExperimentId, PersonId, ExperimentContributionId, GroupCoordinatorId, TimeStart, TimeStop, Comment) VALUES
(1, 1, 1, 2, '2024-01-01', '2024-12-31', 'Leading detector development'),
(1, 2, 2, 1, '2024-01-01', '2024-12-31', 'Software framework development'),
(2, 3, 3, 4, '2024-01-01', '2024-12-31', 'Data analysis coordination');

-- Board
INSERT INTO Board (Id, Name, CollaborationId, Hierarchy) VALUES
(1, 'R3B Collaboration Board', 1, 1),
(2, 'ATLAS Executive Board', 2, 1),
(3, 'NUSTAR Steering Committee', 3, 2);

-- Board Automatic
INSERT INTO BoardAutomatic (BoardId, Reason, SQL) VALUES
(1, 'Institute Representatives', 'SELECT DISTINCT PersonId FROM InstituteRepresentatives WHERE Active = 1'),
(2, 'Working Group Leaders', 'SELECT PersonId FROM WorkgroupFunctions WHERE WorkgroupFunctionId = 1');

-- Email Forward
INSERT INTO EmailForward (Id, CollaborationId, EmailName, Email) VALUES
(1, 1, 'R3B Spokesperson', 'spokesperson@r3b-collaboration.org'),
(2, 2, 'ATLAS Chair', 'chair@atlas-experiment.org');

-- Board Members
INSERT INTO BoardMembers (BoardId, PersonId, InstituteId, CollaborationFunctionId, ElectionDate, ElectionNote) VALUES
(1, 1, 1, 1, '2023-01-01', 'Elected as Spokesperson'),
(2, 2, 2, 2, '2023-01-01', 'Elected as Deputy'),
(3, 4, 1, 3, '2023-06-01', 'Technical Coordinator appointment');

-- Board Rotation
INSERT INTO BoardRotation (BoardId, CollaborationFunctionId, RotationPeriod) VALUES
(1, 1, 24),
(1, 2, 24),
(2, 1, 36);

-- Collaboration Website
INSERT INTO CollaborationWebsite (Id, CollaborationId, URL, LinkName, Description) VALUES
(1, 1, 'https://www.r3b-collaboration.eu/docs', 'Documentation', 'Official R3B documentation'),
(2, 1, 'https://www.r3b-collaboration.eu/meetings', 'Meetings', 'Meeting schedules and minutes'),
(3, 2, 'https://atlas.cern/resources', 'Resources', 'ATLAS collaboration resources');

-- Board Meetings
INSERT INTO BoardMeeting (Id, BoardId, Date, Place) VALUES
(1, '1', '2024-01-15', 'CERN, Geneva'),
(2, '1', '2024-02-20', 'Virtual Meeting'),
(3, '2', '2024-01-10', 'GSI, Darmstadt'),
(4, '2', '2024-03-05', 'MIT, Cambridge'),
(5, '3', '2024-02-15', 'Virtual Meeting');

-- Board Meeting Attendance
INSERT INTO BoardMeetingAttendance (Id, BoardMeetingId, PersonId, InstituteId) VALUES
(1, '1', 1, 1),
(2, '1', 2, 2),
(3, '1', 4, 1),
(4, '2', 1, 1),
(5, '2', 2, 2),
(6, '2', 3, 3),
(7, '3', 3, 3),
(8, '3', 4, 1),
(9, '4', 1, 1),
(10, '4', 5, 2);

-- Collaboration Agreements
INSERT INTO CollaborationAgreement (Id, CollaborationId, BoardMeetingId, IsCurrent, EMailURL) VALUES
(1, 1, 1, TRUE, 'https://www.r3b-nustar.de/member/db/mailarchive/r3b-collaboration-board/'),
(2, 2, 3, TRUE, 'https://atlas.cern/collaboration/board/archive'),
(3, 3, 5, TRUE, 'https://www.nustar.eu/board/archive'),
(4, 1, 2, FALSE, 'https://www.r3b-nustar.de/member/db/mailarchive/r3b-collaboration-board/old');

-- Board Membership Status
INSERT INTO BoardMembershipStatus (Id, CollaborationAgreementId, PersonId, InstituteId, CaSignedOn) VALUES
(1, 1, 1, 1, '2024-01-16'),
(2, 1, 2, 2, '2024-01-16'),
(3, 2, 3, 3, '2024-01-11'),
(4, 2, 4, 1, '2024-01-11'),
(5, 3, 5, 2, '2024-02-16');

-- Member Fee Types
INSERT INTO MemberFeeType (Id, MemberFeeType) VALUES
(1, 'Full Member'),
(2, 'Associate Member'),
(3, 'Observer'),
(4, 'Student Member'),
(5, 'Honorary Member');

-- Collaboration Member Fees
INSERT INTO CollaborationMemberFee (Id, CollaborationId, PersonId, InstituteId, MemberFeeTypeId, ForYear) VALUES
(1, 1, 1, 1, 1, '2024'),
(2, 1, 2, 2, 1, '2024'),
(3, 2, 3, 3, 4, '2024'),
(4, 3, 4, 1, 2, '2024'),
(5, 1, 5, 2, 1, '2024');

-- Requests
INSERT INTO Request (Id, Time, SubmitterId, AddresserId, EmailText, TableName, SQL, Value, Key, CollaborationId, ExecTime, ExecPersonId, ExecState) VALUES
(1, '2024-01-10 09:00:00', 3, 1, 'Request to join R3B collaboration', 'CollaborationMembers', 'INSERT INTO CollaborationMembers (PersonId, CollaborationId) VALUES (3, 1)', 'Membership Request', '1', 1, '2024-01-10 15:00:00', 1, 1),
(2, '2024-02-01 14:30:00', 4, 2, 'Update institute affiliation', 'AdditionalInstituteAffiliations', 'INSERT INTO AdditionalInstituteAffiliations (PersonId, InstituteId) VALUES (4, 2)', 'Institute Update', '2', 2, '2024-02-01 16:00:00', 2, 1),
(3, '2024-03-01 10:00:00', 2, 1, 'Change of work group', 'WorkgroupMembers', 'UPDATE WorkgroupMembers SET WorkgroupId = 2 WHERE PersonId = 2', 'Workgroup Change', '3', 1, '2024-03-01 11:30:00', 1, 1);

-- Special Permission
INSERT INTO SPECIAL_Permission (TableName, Read, Write, SQL) VALUES
('BoardMeeting', 'ALL', 'BOARD_ADMIN', 'SELECT username FROM users WHERE role = ''board_admin'''),
('CollaborationAgreement', 'MEMBER', 'BOARD_ADMIN', 'SELECT username FROM users WHERE role = ''board_admin'''),
('BoardMembershipStatus', 'MEMBER', 'BOARD_ADMIN', 'SELECT username FROM users WHERE role = ''board_admin'''),
('CollaborationMemberFee', 'ADMIN', 'ADMIN', 'SELECT username FROM users WHERE role = ''admin''');

-- Special RelationInfo
INSERT INTO SPECIAL_RelationInfo (TableName, TableHeader, Description, HelpText) VALUES
('BoardMeeting', 'Board Meeting', 'Board meeting information', 'Details about board meetings including date and location'),
('CollaborationAgreement', 'Collaboration Agreement', 'Collaboration agreements', 'Current and historical collaboration agreements'),
('MemberFeeType', 'Member Fee Type', 'Types of membership fees', 'Different categories of membership fees'),
('BoardMembershipStatus', 'Board Membership', 'Board membership information', 'Status of board membership and signing dates');

-- Special ColumnInfo
INSERT INTO SPECIAL_ColumnInfo (TableName, ColumnName, ColumnHeader, HelpText, ExampleText) VALUES
('BoardMeeting', 'Date', 'Meeting Date', 'Date of the board meeting', '2024-01-15'),
('BoardMeeting', 'Place', 'Meeting Location', 'Location where the meeting takes place', 'CERN, Geneva'),
('CollaborationAgreement', 'IsCurrent', 'Current Agreement', 'Indicates if this is the current active agreement', 'true/false'),
('MemberFeeType', 'MemberFeeType', 'Fee Type', 'Type of membership fee', 'Full Member');

-- Special ShortSpec
INSERT INTO SPECIAL_ShortSpec (TableId, SQL) VALUES
(2, 'SELECT BoardMeeting.Date || '' - '' || BoardMeeting.Place AS ShortDesc FROM BoardMeeting'),
(3, 'SELECT ''Agreement-'' || CollaborationAgreement.Id || ''-'' || Collaboration.Name AS ShortDesc FROM CollaborationAgreement JOIN Collaboration ON CollaborationAgreement.CollaborationId = Collaboration.Id');

COMMIT;
