import { Separator } from '@/components/ui/separator'
import { ExternalLink } from 'lucide-react'
import Link from 'next/link'
import React from 'react'

export function Footer() {
  return (
    <footer className="w-full bg-white dark:bg-neutral-950 border-t">
      <div className="mx-auto w-full max-w-screen-xl px-6 py-12">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-12">
          {/* Logo and Tagline */}
          <div className="flex flex-col space-y-4">
            <Link href="/" className="flex items-center">
              <img
                src="/logo/r3b-logo_1000px_alpha.png"
                alt="R3B Logo"
                className="h-16 w-auto"
              />
            </Link>
            <p className="text-sm text-muted-foreground max-w-xs">
              Reactions with Relativistic Radioactive Beams
            </p>
          </div>

          {/* Quick Links */}
          <div className="flex flex-col space-y-6">
            <h3 className="text-base font-semibold tracking-tight">Quick Links</h3>
            <nav className="flex flex-col space-y-4">
              <Link href="/aboutus" className="text-sm text-foreground/80 hover:text-foreground hover:underline underline-offset-4 transition-colors inline-flex">
                About Us
              </Link>
              <Link href="/imprint" className="text-sm text-foreground/80 hover:text-foreground hover:underline underline-offset-4 transition-colors inline-flex">
                Impressum/Legal Notice
              </Link>
              <Link href="mailto:r3b-admin@r3b-nustar.de" className="text-sm text-foreground/80 hover:text-foreground hover:underline underline-offset-4 transition-colors inline-flex">
                Contact Us
              </Link>
            </nav>
          </div>

          {/* Partners */}
          <div className="flex flex-col space-y-6">
            <h3 className="text-base font-semibold tracking-tight">Partners</h3>
            <nav className="flex flex-col space-y-4">
              <ExternalLinkItem
                href="http://www.ikp.tu-darmstadt.de"
                title="IPK Darmstadt"
                label="Technische Universität Darmstadt"
              />
              <ExternalLinkItem
                href="https://fair-center.eu/"
                title="FAIR"
                label="Facility for Antiproton and Ion Research in Europe GmbH"
              />
              <ExternalLinkItem
                href="http://www.gsi.de"
                title="GSI"
                label="GSI Helmholtzzentrum für Schwerionenforschung GmbH"
              />
            </nav>
          </div>
        </div>

        {/* Divider and Copyright */}
        <Separator className="my-8" />
        <div className="flex flex-col sm:flex-row justify-between items-center">
          <p className="text-xs text-muted-foreground">
            ©
            {' '}
            {new Date().getFullYear()}
            {' '}
            R3B. All rights reserved.
          </p>
        </div>
      </div>
    </footer>
  )
}

function ExternalLinkItem({ href, title, label }: any) {
  return (
    <Link
      href={href}
      target="_blank"
      title={title}
      className="text-sm text-foreground/80 hover:text-foreground group transition-colors inline-flex items-center"
    >
      <span className="group-hover:underline underline-offset-4">{label}</span>
      <ExternalLink className="ml-1 h-3 w-3 opacity-70 group-hover:opacity-100" />
    </Link>
  )
}

export default Footer
