import { Badge } from '@/components/ui/badge'
import { cn } from '@/lib/utils'
import React from 'react'

type TagColor = 'blue' | 'green' | 'red' | 'purple' | 'orange' | 'gray'

interface TagProps {
  name: string
  color?: TagColor
  className?: string
}

function getColorClasses(color: TagColor) {
  const colorMap: Record<TagColor, string> = {
    blue: 'bg-blue-600 hover:bg-blue-500 dark:bg-blue-800 dark:hover:bg-blue-700 text-white',
    green: 'bg-green-600 hover:bg-green-500 dark:bg-green-800 dark:hover:bg-green-700 text-white',
    red: 'bg-red-600 hover:bg-red-500 dark:bg-red-800 dark:hover:bg-red-700 text-white',
    purple: 'bg-purple-600 hover:bg-purple-500 dark:bg-purple-800 dark:hover:bg-purple-700 text-white',
    orange: 'bg-orange-600 hover:bg-orange-500 dark:bg-orange-800 dark:hover:bg-orange-700 text-white',
    gray: 'bg-gray-600 hover:bg-gray-500 dark:bg-gray-800 dark:hover:bg-gray-700 text-white',
  }

  return colorMap[color]
}

function Tag(props: TagProps) {
  const { name, color = 'blue', className } = props

  return (
    <Badge
      className={cn(
        'font-medium transition-colors border-none cursor-pointer',
        getColorClasses(color),
        className,
      )}
    >
      {name}
    </Badge>
  )
}

export default Tag
