'use client'

import { EmptyState } from './components/states/EmptyState'
import { ErrorState } from './components/states/ErrorState'
import { LoadedState } from './components/states/LoadedState'
import { LoadingState } from './components/states/LoadingState'
import { useCalendarEvents } from './hooks/useCalendarEvents'

export default function CalendarWidget() {
  const { events, isLoading, weekRange, error, refetch, navigateWeek } = useCalendarEvents()

  if (error) {
    return (
      <ErrorState
        formattedTimeRange={weekRange.formatted}
        onPrevious={() => { navigateWeek('previous') }}
        onNext={() => { navigateWeek('next') }}
        error={error}
        onRetry={refetch}
      />
    )
  }

  if (isLoading) {
    return (
      <LoadingState
        formattedTimeRange={weekRange.formatted}
        onPrevious={() => { navigateWeek('previous') }}
        onNext={() => { navigateWeek('next') }}
      />
    )
  }

  if (events.length === 0) {
    return (
      <EmptyState
        formattedTimeRange={weekRange.formatted}
        onPrevious={() => { navigateWeek('previous') }}
        onNext={() => { navigateWeek('next') }}
      />
    )
  }

  return (
    <LoadedState
      events={events}
      weekRange={weekRange.formatted}
      onNavigateWeek={navigateWeek}
      startDate={weekRange.start}
    />
  )
}
