import React from 'react'
import { CalendarCard } from '../CalendarCard'
import { CalendarHeader } from '../CalendarHeader'

interface LoadingStateProps {
  formattedTimeRange: string
  onPrevious: () => void
  onNext: () => void
}

function EventCardSkeleton() {
  return (
    <div className="bg-blue-500 dark:bg-blue-400 p-4 rounded-lg cursor-pointer hover:bg-blue-600 dark:hover:bg-blue-500 transition-colors">
      <div className="animate-pulse">
        <div className="h-6 bg-blue-400 dark:bg-blue-300 rounded w-1/3 mb-2"></div>
        <div className="h-5 bg-blue-400 dark:bg-blue-300 rounded w-1/2"></div>
      </div>
    </div>
  )
}

function DayColumnSkeleton() {
  return (
    <div className="w-16 flex flex-col animate-pulse">
      <div className="h-4 bg-gray-300 dark:bg-gray-700 rounded w-8 mb-1"></div>
      <div className="w-12 h-12 bg-gray-300 dark:bg-gray-700 rounded-full flex items-center justify-center">
      </div>
    </div>
  )
}

function DayRowSkeleton() {
  return (
    <div className="flex items-start gap-4">
      <DayColumnSkeleton />
      <div className="flex-1">
        <EventCardSkeleton />
      </div>
    </div>
  )
}

export function LoadingState({ formattedTimeRange, onPrevious, onNext }: LoadingStateProps) {
  return (
    <CalendarCard>
      <CalendarHeader
        formattedTimeRange={formattedTimeRange}
        onPrevious={onPrevious}
        onNext={onNext}
      />
      <div className="space-y-4">
        <DayRowSkeleton />
      </div>
    </CalendarCard>
  )
}
