import { Card, CardContent } from '@/components/ui/card'
import config from '@/payload.config'
import { BookOpen, Newspaper } from 'lucide-react'
import Image from 'next/image'
import Link from 'next/link'
import { getPayload } from 'payload'

interface Detector {
  id: string
  detectorName: string
  description: string
  slug: string
  featuredImage?: {
    url: string
    width: number
    height: number
    alt: string
  }
}

export default async function DetectorPage() {
  const payload = await getPayload({ config })

  const result = await payload.find({
    collection: 'detectors',
  })

  const articles = result.docs as unknown as Detector[]
  const remainingArticles = articles.length > 0 ? articles : []
  return (
    <main className="bg-gray-50 dark:bg-neutral-950 min-h-screen pb-16 md:pt-5 pt-16">
      <div className="container mx-auto px-4">
        {remainingArticles.length > 0
          ? (
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
                {remainingArticles.map(article => (
                  <Link
                    key={article.id}
                    href={`/detectors/${article.slug}`}
                    className="group"
                  >
                    <Card className="overflow-hidden h-full flex flex-col bg-white dark:bg-neutral-800 border border-gray-200 dark:border-neutral-700 group-hover:border-red-300 dark:group-hover:border-red-800 transition-colors shadow-sm group-hover:shadow-md">
                      <div className="relative w-full h-48 overflow-hidden bg-gray-200 dark:bg-neutral-700">
                        {article.featuredImage && article.featuredImage.url
                          ? (
                              <Image
                                src={article.featuredImage.url}
                                alt={article.featuredImage.alt || article.detectorName}
                                fill
                                className="object-cover transition-transform group-hover:scale-105"
                              />
                            )
                          : (
                              <div className="w-full h-full flex items-center justify-center">
                                <Newspaper className="w-12 h-12 text-gray-400 dark:text-neutral-500" />
                              </div>
                            )}
                      </div>

                      <CardContent className="flex-grow flex flex-col p-5">
                        <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3 line-clamp-2 group-hover:text-red-600 dark:group-hover:text-red-400 transition-colors">
                          {article.detectorName}
                        </h3>

                        {article.description && (
                          <p className="text-gray-600 dark:text-gray-300 mb-4 line-clamp-3 flex-grow">
                            {article.description}
                          </p>
                        )}

                        <div className="flex items-center text-red-600 dark:text-red-400 mt-auto pt-2 text-sm font-medium">
                          <BookOpen className="w-4 h-4 mr-1" />
                          <span>Read more</span>
                        </div>
                      </CardContent>
                    </Card>
                  </Link>
                ))}
              </div>
            )
          : (
              <Card className="p-12 text-center bg-white dark:bg-neutral-800">
                <p className="text-gray-500 dark:text-gray-400">No detectors found</p>
              </Card>
            )}
      </div>
    </main>
  )
}
