'use client'
import { Accordion, AccordionContent, AccordionItem, AccordionTrigger } from '@/components/ui/accordion'
import { Card, CardContent } from '@/components/ui/card'
import config from '@/payload.config'
import { BookOpen, Calendar, ChevronDown, ChevronRight, Filter, Info, Newspaper, Search, User } from 'lucide-react'
import Image from 'next/image'
import ExperimentSection from './ExperimentSection'

interface Experiment {
  id: string
  number: string
  title: string
  year: string
  speaker: {
    name: string
    link: string
  }
  groupleader: {
    name: string
    email: string
  }
  previewText: string
  featuredImage?: {
    url: string
    width: number
    height: number
    alt: string
  }
}

interface ExperimentProps {
  experiment: Experiment
}

export default function experimentCard({ experiment }: ExperimentProps) {
  return (
    <div>
      {experiment && experiment.groupleader
        ? (
            <Card key={experiment.id} className="overflow-hidden h-full flex flex-col bg-white dark:bg-neutral-800 border border-gray-200 dark:border-neutral-700 group-hover:border-red-300 dark:group-hover:border-red-800 transition-colors shadow-sm group-hover:shadow-md">
              <div className="relative w-full h-48 overflow-hidden bg-gray-200 dark:bg-neutral-700">
                {experiment.featuredImage && experiment.featuredImage.url
                  ? (
                      <Image
                        src={experiment.featuredImage.url}
                        alt={experiment.featuredImage.alt || experiment.title}
                        fill
                        className="object-cover transition-transform group-hover:scale-105"
                      />
                    )
                  : (
                      <div className="w-full h-full flex items-center justify-center">
                        <Newspaper className="w-12 h-12 text-gray-400 dark:text-neutral-500" />
                      </div>
                    )}
              </div>

              <CardContent className="flex-grow flex flex-col p-5">

                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3 line-clamp-2 group-hover:text-red-600 dark:group-hover:text-red-400 transition-colors">
                  {experiment.title}
                </h3>

                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3 line-clamp-2 group-hover:text-red-600 dark:group-hover:text-red-400 transition-colors">
                  {experiment.number}
                </h3>

                <Accordion
                  className="AccordionRoot border-gray-200 border-t"
                  type="single"
                  defaultValue="null"
                  collapsible
                >
                  <AccordionItem className="AccordionItem" value="item-1">
                    <AccordionTrigger>
                      <div className="flex items-center text-red-600 dark:text-red-400 mt-auto pt-2 text-sm font-medium">
                        <Info className="w-4 h-4 mr-1" />
                        <span>more Details</span>
                      </div>
                    </AccordionTrigger>
                    <AccordionContent>
                      <div>
                        <div>
                          {'From the year: '}
                          {experiment.year}
                        </div>
                        <div>
                          {experiment.groupleader.name}
                          {' '}
                          {experiment.groupleader.email}
                        </div>
                        <div>
                          {experiment.speaker.name}
                          {' '}
                          {experiment.speaker.link}
                        </div>
                        <div>
                          {experiment.previewText && (
                            <p className="text-gray-600 dark:text-gray-300 mb-4 flex-grow">
                              {experiment.previewText}
                            </p>
                          )}
                        </div>
                      </div>
                    </AccordionContent>
                  </AccordionItem>
                </Accordion>

              </CardContent>
            </Card>
          )
        : (
            <div> experiment cant load</div>
          )}
    </div>
  )
}
