'use client'
import { Card } from '@/components/ui/card'
import ExperimentCard from './ExperimentCard'

interface Experiment {
  id: string
  number: string
  title: string
  year: string
  speaker: {
    name: string
    link: string
  }
  groupleader: {
    name: string
    email: string
  }
  previewText: string
  featuredImage?: {
    url: string
    width: number
    height: number
    alt: string
  }
}

interface ExperimentProps {
  experiments: Experiment[]
}

export default function ExperimentSection({ experiments }: ExperimentProps) {
  return (

    <main className="bg-gray-50 dark:bg-neutral-950 min-h-screen pb-16 md:pt-5">
      <div className="container mx-auto px-4">
        <div className="flex flex-col px-4 items-center justify-center">

          <div className="w-full grid grid-cols-1 gap-8 ">
            {experiments.length > 0
              ? (
                  experiments.map(experiment => (
                    <div key={experiment.id} className="group">
                      <ExperimentCard experiment={experiment} />
                    </div>
                  ))
                )
              : (
                  <Card className="p-12 text-center bg-white dark:bg-neutral-800">
                    <p className="text-gray-500 dark:text-gray-400">No experiments found</p>
                  </Card>
                )}
          </div>
        </div>
      </div>
    </main>
  )
}
