import type { CollectionConfig } from 'payload'
import { lexicalEditor } from '@payloadcms/richtext-lexical'

export const Detectors: CollectionConfig = {
  slug: 'detectors',
  labels: {
    singular: 'Detector',
    plural: 'Detectors',
  },
  access: {
    read: () => true,
  },
  fields: [
    {
      name: 'detectorName',
      label: 'detector name',
      type: 'text',
      required: true,
    },
    {
      name: 'description',
      label: 'description',
      type: 'text',
      required: true,
    },
    {
      name: 'slug',
      type: 'text',
      required: true,
      unique: true,
      admin: {
        description: 'URL-friendly version of the detector name',
        position: 'sidebar',
      },
      hooks: {
        beforeValidate: [
          ({ value, siblingData }) => {
            if (!value && siblingData?.headline) {
              return siblingData.headline
                .toLowerCase()
                .trim()
                .replace(/[^\w\s]/g, '')
                .replace(/\s+/g, '-')
            }
            return value
          },
        ],
      },
    },
    {
      name: 'content',
      type: 'richText',
      label: 'Article Content',
      required: true,
      editor: lexicalEditor({
        features: ({ defaultFeatures, rootFeatures }) => [
          ...defaultFeatures,
          ...rootFeatures,
        ],
      }),
    },
    {
      name: 'featuredImage',
      type: 'upload',
      relationTo: 'news-article-images',
      label: 'Featured Image',
      admin: {
        description: 'The main image for the detector page',
      },
    },
  ],
}
