import type { CollectionConfig } from 'payload'

export const Tags: CollectionConfig = {
  slug: 'tags',
  labels: {
    singular: 'Tag',
    plural: 'Tags',
  },
  access: {
    read: () => true,
  },
  admin: {
    useAsTitle: 'name',
    description: 'Create and manage tags for categorizing news articles',
  },
  fields: [
    {
      name: 'name',
      type: 'text',
      required: true,
      label: 'Tag Name',
      admin: {
        description: 'The name of the tag (e.g., Politics, Technology, Sports)',
      },
    },
    {
      name: 'slug',
      type: 'text',
      required: true,
      unique: true,
      admin: {
        description: 'URL-friendly version of the tag name (auto-generated)',
        position: 'sidebar',
      },
      hooks: {
        beforeValidate: [
          ({ data }) => {
            if (data && data.name) {
              return data.name
                .toLowerCase()
                .replace(/[^\w\s]/g, '')
                .replace(/\s+/g, '-')
            }
            return ''
          },
        ],
      },
    },
    {
      name: 'description',
      type: 'textarea',
      required: false,
      label: 'Description',
      admin: {
        description: 'Optional description of what this tag represents',
      },
    },
    {
      name: 'color',
      type: 'select',
      required: false,
      label: 'Color',
      options: [
        {
          label: 'Blue',
          value: 'blue',
        },
        {
          label: 'Green',
          value: 'green',
        },
        {
          label: 'Red',
          value: 'red',
        },
        {
          label: 'Purple',
          value: 'purple',
        },
        {
          label: 'Orange',
          value: 'orange',
        },
        {
          label: 'Gray',
          value: 'gray',
        },
      ],
      defaultValue: 'blue',
      admin: {
        description: 'Color used to highlight this tag',
        position: 'sidebar',
      },
    },
    {
      name: 'featured',
      type: 'checkbox',
      label: 'Featured Tag',
      defaultValue: false,
      admin: {
        description: 'Display this tag prominently (e.g., in navigation)',
        position: 'sidebar',
      },
    },
  ],
  timestamps: true,
}
