/* eslint-disable react/no-array-index-key */
import type { SerializedListItemNode, SerializedListNode, SerializedTextNode } from '@payloadcms/richtext-lexical'
import type { SerializedLexicalNode } from '@payloadcms/richtext-lexical/lexical'
import { Checkbox } from '@/components/ui/checkbox'
import React from 'react'

function isTextNode(node: SerializedLexicalNode): node is SerializedTextNode {
  return node.type === 'text'
}

function isListItemNode(node: SerializedLexicalNode): node is SerializedListItemNode {
  return node.type === 'listitem'
}

function ListItemContent({ nodes, id }: { nodes: SerializedLexicalNode[], id: string }) {
  return (
    <>
      {nodes.map((node, index) => {
        if (isTextNode(node)) {
          return <span key={index}>{node.text}</span>
        }
        if (isListItemNode(node) && node.children) {
          return <ListItemContent key={index} nodes={node.children} id={`${id}-${index}`} />
        }
        return null
      })}
    </>
  )
}

export default function CustomCheckboxList({ node }: { node: SerializedListNode }) {
  return (
    <ul className="my-6 space-y-3">
      {node.children.map((child, index) => {
        if (isListItemNode(child)) {
          const id = `checkbox-${index}`
          return (
            <li key={index} className="list-none">
              <div className="flex items-start gap-2">
                <Checkbox id={id} className="mt-1" />
                <label
                  htmlFor={id}
                  className="text-sm font-medium leading-normal cursor-pointer"
                >
                  <ListItemContent nodes={child.children} id={id} />
                </label>
              </div>
            </li>
          )
        }
        return null
      })}
    </ul>
  )
}
