/* eslint-disable react/no-array-index-key */
import type { SerializedHeadingNode, SerializedTextNode } from '@payloadcms/richtext-lexical'
import type { SerializedLexicalNode } from '@payloadcms/richtext-lexical/lexical'
import React from 'react'

function isTextNode(node: SerializedLexicalNode): node is SerializedTextNode {
  return node.type === 'text'
}

function isHeadingNode(node: SerializedLexicalNode): node is SerializedHeadingNode {
  return node.type === 'heading'
}

function HeadingContent({ nodes }: { nodes: SerializedLexicalNode[] }) {
  return (
    <>
      {nodes.map((node, index) => {
        if (isTextNode(node)) {
          return <span key={`${node.text}-${index}`}>{node.text}</span>
        }
        if (isHeadingNode(node) && node.children) {
          return <HeadingContent key={index} nodes={node.children} />
        }
        return null
      })}
    </>
  )
}

export default function CustomHeading({ node }: { node: SerializedHeadingNode }) {
  switch (node.tag) {
    case 'h1':
      return (
        <h1 className="scroll-m-20 text-4xl font-extrabold tracking-tight lg:text-5xl">
          <HeadingContent nodes={node.children} />
        </h1>
      )
    case 'h2':
      return (
        <h2 className="scroll-m-20 border-b pb-2 text-3xl font-semibold tracking-tight first:mt-0">
          <HeadingContent nodes={node.children} />
        </h2>
      )
    case 'h3':
      return (
        <h3 className="scroll-m-20 text-2xl font-semibold tracking-tight">
          <HeadingContent nodes={node.children} />
        </h3>
      )
    case 'h4':
      return (
        <h4 className="scroll-m-20 text-xl font-semibold tracking-tight">
          <HeadingContent nodes={node.children} />
        </h4>
      )
    case 'h5':
      return (
        <h5 className="text-md font-semibold">
          <HeadingContent nodes={node.children} />
        </h5>
      )
    case 'h6':
      return (
        <h6 className="text-sm font-semibold">
          <HeadingContent nodes={node.children} />
        </h6>
      )
  }
}
