/* eslint-disable react/no-array-index-key */
import type { SerializedLinkNode } from '@payloadcms/richtext-lexical'
import type { SerializedLexicalNode, SerializedTextNode } from '@payloadcms/richtext-lexical/lexical'
import { cn } from '@/lib/utils'
import { ExternalLink } from 'lucide-react'
import Link from 'next/link'

function isTextNode(node: SerializedLexicalNode): node is SerializedTextNode {
  return 'text' in node
}

export default function CustomLink({ node }: { node: SerializedLinkNode }) {
  const isExternal = node.fields?.url?.startsWith('http') || false

  return (
    <Link
      href={node.fields?.url || ''}
      target={node.fields.newTab ? '_blank' : undefined}
      rel={node.fields.newTab ? 'noopener noreferrer' : undefined}
      className={cn(
        'font-medium text-r3b-orange hover:text-red-800 transition-colors duration-200',
        'underline decoration-red-400 underline-offset-2 hover:decoration-red-600',
        'inline-flex items-center gap-1 group',
      )}
    >
      {node.children.map((child: SerializedLexicalNode, index: number) => {
        if (isTextNode(child)) {
          return <span key={index}>{child.text}</span>
        }
        return <span key={index}></span>
      })}

      {isExternal && (
        <ExternalLink
          size={14}
          className="inline-block opacity-70 group-hover:opacity-100 transition-opacity"
        />
      )}
    </Link>
  )
}
