/* eslint-disable react/no-array-index-key */
import type { SerializedListItemNode, SerializedListNode, SerializedTextNode } from '@payloadcms/richtext-lexical'
import type { SerializedLexicalNode } from '@payloadcms/richtext-lexical/lexical'
import React from 'react'

function isTextNode(node: SerializedLexicalNode): node is SerializedTextNode {
  return node.type === 'text'
}

function isListItemNode(node: SerializedLexicalNode): node is SerializedListItemNode {
  return node.type === 'listitem'
}

function ListItemContent({ nodes }: { nodes: SerializedLexicalNode[] }) {
  return (
    <>
      {nodes.map((node, index) => {
        if (isTextNode(node)) {
          return <span key={index}>{node.text}</span>
        }
        if (isListItemNode(node) && node.children) {
          return <ListItemContent key={index} nodes={node.children} />
        }
        return null
      })}
    </>
  )
}

export default function CustomOrderedList({ node }: { node: SerializedListNode }) {
  return (
    <ol className="my-6 ml-4 list-decimal [&>li]:mt-2">
      {node.children.map((child, index) => {
        if (isListItemNode(child)) {
          return (
            <li key={index}>
              <ListItemContent nodes={child.children} />
            </li>
          )
        }
        return null
      })}
    </ol>
  )
}
