/* eslint-disable react/no-array-index-key */
import type { SerializedQuoteNode, SerializedTextNode } from '@payloadcms/richtext-lexical'
import type { SerializedLexicalNode } from '@payloadcms/richtext-lexical/lexical'

function isTextNode(node: SerializedLexicalNode): node is SerializedTextNode {
  return node.type === 'text'
}

function isQuoteNode(node: SerializedLexicalNode): node is SerializedQuoteNode {
  return node.type === 'quote'
}

function QuoteContent({ nodes }: { nodes: SerializedLexicalNode[] }) {
  return (
    <>
      {nodes.map((node, index) => {
        if (isTextNode(node)) {
          return <span key={`${node.text}-${index}`}>{node.text}</span>
        }
        if (isQuoteNode(node) && node.children) {
          return <QuoteContent key={index} nodes={node.children} />
        }
        return null
      })}
    </>
  )
}

export default function CustomQuote({ node }: { node: SerializedQuoteNode }) {
  return (
    <blockquote className="mt-6 border-l-2 pl-6 italic">
      <QuoteContent nodes={node.children} />
    </blockquote>
  )
}
