import type { SerializedUploadNode } from '@payloadcms/richtext-lexical'
import Image from 'next/image'

function getImageData(value: unknown): { url: string, alt: string, width: number, height: number } | null {
  if (!value || typeof value !== 'object')
    return null

  return value as { url: string, alt: string, width: number, height: number }
}

export default function CustomUpload({ node }: { node: SerializedUploadNode }) {
  if (node.relationTo !== 'media')
    return null

  const imageData = getImageData(node.value)
  if (!imageData)
    return null

  const { url, alt = 'Upload image', width = 400, height = 300 } = imageData

  return (
    <Image
      src={url}
      alt={alt}
      width={width}
      height={height}
      loading="lazy"
      className="mb-8 relative rounded-lg overflow-hidden"
    />
  )
}
