import type { DefaultNodeTypes, SerializedHeadingNode, SerializedLinkNode, SerializedListNode, SerializedQuoteNode, SerializedTableNode, SerializedUploadNode } from '@payloadcms/richtext-lexical'
import type { SerializedParagraphNode } from '@payloadcms/richtext-lexical/lexical'
import type { JSXConvertersFunction } from '@payloadcms/richtext-lexical/react'
import { convertLexicalNodesToJSX } from 'node_modules/@payloadcms/richtext-lexical/dist/exports/react/components/RichText/converter'
import React from 'react'
import CustomCheckboxList from './components/CustomCheckList'
import CustomHeading from './components/CustomHeadinng'
import CustomLink from './components/CustomLink'
import CustomOrderedList from './components/CustomOrderedList'
import CustomQuote from './components/CustomQuote'
import CustomUnorderedList from './components/CustomUnorderedList'
import CustomUpload from './components/CustomUpload'

export const createLexicalJSXConverters: JSXConvertersFunction<DefaultNodeTypes> = ({ defaultConverters }) => {
  return {
    ...defaultConverters,

    upload: ({ node }: { node: SerializedUploadNode }) => {
      return <CustomUpload node={node} />
    },

    link: ({ node }: { node: SerializedLinkNode }) => {
      return <CustomLink node={node} />
    },

    list: ({ node }: { node: SerializedListNode }) => {
      if (node.listType === 'bullet')
        return <CustomUnorderedList node={node} />
      if (node.listType === 'number')
        return <CustomOrderedList node={node} />
      if (node.listType === 'check')
        return <CustomCheckboxList node={node} />
      else
        return <CustomUnorderedList node={node} />
    },

    heading: ({ node }: { node: SerializedHeadingNode }) => {
      return (
        <CustomHeading node={node} />
      )
    },
    quote: ({ node }: { node: SerializedQuoteNode }) => {
      return (
        <CustomQuote node={node} />
      )
    },
    table: ({ node }: { node: SerializedTableNode }) => {
      return (
        <div className="my-6 w-full overflow-y-auto">
          <table className="w-full">
            <tbody>
              {convertLexicalNodesToJSX({ converters: defaultConverters, nodes: node.children, parent: node })}
            </tbody>
          </table>
        </div>
      )
    },
    paragraph: ({ node }: { node: SerializedParagraphNode }) => {
      return (
        <div className="leading-7 [&:not(:first-child)]:mt-6">
          {convertLexicalNodesToJSX({ converters: defaultConverters, nodes: node.children, parent: node })}
        </div>
      )
    },
  }
}
