import path from 'node:path'
import process from 'node:process'
import { fileURLToPath } from 'node:url'
// storage-adapter-import-placeholder
import { mongooseAdapter } from '@payloadcms/db-mongodb'
import { EXPERIMENTAL_TableFeature, FixedToolbarFeature, lexicalEditor } from '@payloadcms/richtext-lexical'

import { buildConfig } from 'payload'
import sharp from 'sharp'
import { Detectors } from './collections/Detectors'
import { Event } from './collections/Event'
import { Experiments } from './collections/Experiments'
import { Media } from './collections/Media'
import { NewsArticleImages } from './collections/NewsArticleImages'
import { NewsArticles } from './collections/NewsArticles'
import { PublicationDocuments } from './collections/PublicationDocuments'
import { Publications } from './collections/Publications'
import { SlideshowImages } from './collections/SlideshowImages'
import { Tags } from './collections/Tags'
import { Users } from './collections/Users'

const filename = fileURLToPath(import.meta.url)
const dirname = path.dirname(filename)

export default buildConfig({
  admin: {
    user: Users.slug,
    importMap: {
      baseDir: path.resolve(dirname),
    },
  },

  collections: [Users, Media, SlideshowImages, Publications, PublicationDocuments, Detectors, NewsArticles, NewsArticleImages, Tags, Event, Experiments],

  editor: lexicalEditor({
    features: ({ defaultFeatures }) => [
      ...defaultFeatures,
      EXPERIMENTAL_TableFeature(),
      FixedToolbarFeature(),
    ],
  }),
  secret: process.env.PAYLOAD_SECRET || '',
  typescript: {
    outputFile: path.resolve(dirname, 'payload-types.ts'),
  },
  db: mongooseAdapter({
    url: process.env.DATABASE_URI || '',
  }),
  sharp,
  plugins: [
    // storage-adapter-placeholder
  ],
})
